==> kubernetes-model-core-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/PodResourceClaimFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface PodResourceClaimFluent<A extends PodResourceClaimFluent<A>> extends Fluent<A>{
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  
  /**
   * This method has been deprecated, please use method buildSource instead.
   * @return The buildable object.
   */
  @Deprecated
  public ClaimSource getSource();
  public ClaimSource buildSource();
  public A withSource(ClaimSource source);
  public Boolean hasSource();
  public A withNewSource(String resourceClaimName,String resourceClaimTemplateName);
  public PodResourceClaimFluent.SourceNested<A> withNewSource();
  public PodResourceClaimFluent.SourceNested<A> withNewSourceLike(ClaimSource item);
  public PodResourceClaimFluent.SourceNested<A> editSource();
  public PodResourceClaimFluent.SourceNested<A> editOrNewSource();
  public PodResourceClaimFluent.SourceNested<A> editOrNewSourceLike(ClaimSource item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface SourceNested<N> extends Nested<N>,ClaimSourceFluent<PodResourceClaimFluent.SourceNested<N>>{
    public N and();
    public N endSource();
    
  }
  
}

==> kubernetes-model-core-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/PodResourceClaimFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodResourceClaimFluent<A extends PodResourceClaimFluent<A>> extends Fluent<A>{
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  
  /**
   * This method has been deprecated, please use method buildSource instead.
   * @return The buildable object.
   */
  @Deprecated
  public ClaimSource getSource();
  public ClaimSource buildSource();
  public A withSource(ClaimSource source);
  public Boolean hasSource();
  public A withNewSource(String resourceClaimName,String resourceClaimTemplateName);
  public PodResourceClaimFluent.SourceNested<A> withNewSource();
  public PodResourceClaimFluent.SourceNested<A> withNewSourceLike(ClaimSource item);
  public PodResourceClaimFluent.SourceNested<A> editSource();
  public PodResourceClaimFluent.SourceNested<A> editOrNewSource();
  public PodResourceClaimFluent.SourceNested<A> editOrNewSourceLike(ClaimSource item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface SourceNested<N> extends Nested<N>,ClaimSourceFluent<PodResourceClaimFluent.SourceNested<N>>{
    public N and();
    public N endSource();
    
  }
  
}
